nikola.packages.tzlocal package
===============================

.. automodule:: nikola.packages.tzlocal
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

nikola.packages.tzlocal.unix module
-----------------------------------

.. automodule:: nikola.packages.tzlocal.unix
   :members:
   :undoc-members:
   :show-inheritance:

nikola.packages.tzlocal.win32 module
------------------------------------

.. automodule:: nikola.packages.tzlocal.win32
   :members:
   :undoc-members:
   :show-inheritance:

nikola.packages.tzlocal.windows\_tz module
------------------------------------------

.. automodule:: nikola.packages.tzlocal.windows_tz
   :members:
   :undoc-members:
   :show-inheritance:

